@@ -10,7 +10,7 @@ from lightwood.ensemble.base import BaseEnsemble
 from lightwood.api.types import PredictionArguments
 from lightwood.data.encoded_ds import EncodedDs
 from lightwood.helpers.general import evaluate_accuracy
-from lightwood import dtype
+from type_infer.dtype import dtype
 
 
 class WeightedMeanEnsemble(BaseEnsemble):
